@@ -12,11 +12,12 @@ from pandas.api.types import (
 
 def partialdep(func, X, y, var):
     """Plot partial dependence"""
-    if is_bool_dtype(X[var]) or is_object_dtype(X[var]):
-        X[var] = X[var].astype("category")
-
     if is_categorical_dtype(X[var]):
         return partialdep_cat(func, X, y, var)
+    elif is_bool_dtype(X[var]):
+        return partialdep_cat(func, X, y, var)
+    elif is_object_dtype(X[var]):
+        return partialdep_cat(func, X, y, var)
     elif is_numeric_dtype(X[var]):
         return partialdep_num(func, X, y, var)
     elif is_datetime64_any_dtype(X[var]):
@@ -94,21 +95,35 @@ def partialdep_num(func, X, y, var):
     return lines + mean
 
 
-def partialdep_cat(func, X, y, var, n_max=100, n_sample=50):
+def partialdep_cat(func, X, y, var, n_categories=100, n_sample=50):
     """Plot partial dependence for categorical variables"""
 
-    ordered_categories = list(X[var].cat.categories)[:n_max]
+    # use ordering of categorical if available
+    if is_categorical_dtype(X[var]):
+        ordered_categories = list(X[var].cat.categories)[:n_categories]
+    else:
+        ordered_categories = X[var].unique()
+
     df_plot = pd.DataFrame()
 
     for q in ordered_categories:
         X_mod = X.copy()
-        X_mod[var] = pd.Categorical(np.repeat(q, len(X)))
+        X_mod[var] = pd.Series([q] * len(X), dtype=X[var].dtype)
         pred_q = func(X_mod)
         rowid = np.arange(len(X_mod))
-        df_plot_q = pd.DataFrame({"id": rowid, var: q, "Predicted Value": pred_q})
+        df_plot_q = pd.DataFrame(
+            {"id": rowid, var: X_mod[var], "Predicted Value": pred_q}
+        )
         df_plot = df_plot.append(df_plot_q, ignore_index=True, sort=False)
 
-    df_plot[var] = df_plot[var].astype("category")
+    # Convert to categorical for plotting
+    df_plot[var] = (
+        df_plot[var]
+        .astype("category")
+        .cat.add_categories("Missing")
+        .fillna("Missing")
+        .cat.remove_unused_categories()
+    )
 
     df_plot_summary = (
         df_plot.groupby(var)
@@ -126,7 +141,11 @@ def partialdep_cat(func, X, y, var, n_max=100, n_sample=50):
         .mark_line(strokeOpacity=0.3, color="grey", strokeWidth=2)
         .encode(
             x=alt.X("Predicted Value", scale=alt.Scale(zero=False)),
-            y=alt.Y(var, sort=ordered_categories),
+            y=alt.Y(
+                var,
+                sort=df_plot[var].cat.categories.to_list(),
+                scale=alt.Scale(zero=False),
+            ),
             detail="id",
         )
     )
@@ -135,7 +154,11 @@ def partialdep_cat(func, X, y, var, n_max=100, n_sample=50):
         .mark_line(point=True, width=3)
         .encode(
             x="Predicted Value",
-            y=alt.Y(var, sort=ordered_categories, scale=alt.Scale(zero=False)),
+            y=alt.Y(
+                var,
+                sort=df_plot[var].cat.categories.to_list(),
+                scale=alt.Scale(zero=False),
+            ),
             tooltip=[var, alt.Tooltip(f"Predicted Value:Q", format=".2f")],
         )
         .interactive()
