@@ -5,7 +5,7 @@ import pandas as pd
 from profiling.metrics import getloss
 
 
-def varimp(func, X, y, metric="Rmse", n_max=10000):
+def varimp(func, X, y, metric="Rmse", n_max=10000, feat_max=25):
 
     # Sample from large dataframes
     if len(X) > n_max:
@@ -50,6 +50,9 @@ def varimp(func, X, y, metric="Rmse", n_max=10000):
             .rename(columns={"delta": "Relative Importance"})
         )
 
+    #  Cut off features for chart at feat_max
+    df = df.iloc[:feat_max, :]
+
     chart = (
         alt.Chart(df)
         .mark_bar()
