@@ -1,51 +1,10 @@
-import json
-import logging
 import math
-import os
 from abc import ABC, abstractmethod
 from functools import lru_cache
 from itertools import combinations
 
 import numpy as np
 import pandas as pd
-from fastapi.encoders import jsonable_encoder
-
-from profiling.utils import create_description, df_to_dict
-
-
-def create_shapley_schema(endpoint, basepath="results"):
-    """Create shapley schema for endpoint"""
-    name = endpoint.func.__name__
-    explainer = ShapExplainer(func=endpoint.func, X=endpoint.X)
-    folder = os.path.join(basepath, endpoint.func.__name__)
-    input_descriptions = [create_description(endpoint.X[col]) for col in endpoint.X]
-    if not os.path.exists(folder):
-        os.makedirs(folder)
-
-    logging.info("Shapley - Creating schema")
-    fname = "schema.json"
-    fpath = os.path.join(folder, fname)
-    data = create_explainer_schema(endpoint, explainer, input_descriptions)
-    with open(fpath, "w") as f:
-        json.dump(jsonable_encoder(data), f)
-
-
-def create_explainer_schema(endpoint, explainer, input_descriptions):
-    """Create schema for explainer input"""
-    # create an example
-    name = endpoint.func.__name__
-    X = endpoint.X.sample(n=1)
-    pred = endpoint.func(X)
-    baseline, explanation = explainer.explain(X)
-    example = {
-        "inputs": df_to_dict(X),
-        "explanations": df_to_dict(explanation),
-        "prediction": list(pred),
-        "baseline": list(baseline),
-    }
-    # build schema
-    schema = {"input_descriptions": input_descriptions, "example": example}
-    return schema
 
 
 @lru_cache(maxsize=256)
